@@ -220,26 +220,41 @@ class SystemPromptManager:
         if self.agent.system_prompt:
             base_prompt = self.agent.system_prompt
         
-        else:
-            has_any_info = False
+        has_any_info = False
 
-            if self.agent.role:
-                base_prompt += f"\nThis is your role: {self.agent.role}"
-                has_any_info = True
-            if self.agent.goal:
-                base_prompt += f"\nThis is your goal: {self.agent.goal}"
-                has_any_info = True
-            if self.agent.instructions:
-                base_prompt += f"\nThis is your instructions to follow: {self.agent.instructions}"
-                has_any_info = True
-            if self.agent.education:
-                base_prompt += f"\nThis is your education: {self.agent.education}"
-                has_any_info = True
-            if self.agent.work_experience:
-                base_prompt += f"\nThis is your work experiences: {self.agent.work_experience}"
-                has_any_info = True
-            if not has_any_info and not is_thinking_enabled:
-                base_prompt = default_prompt().prompt
+        if self.agent.role:
+            base_prompt += f"\nThis is your role: {self.agent.role}"
+            has_any_info = True
+        if self.agent.goal:
+            base_prompt += f"\nThis is your goal: {self.agent.goal}"
+            has_any_info = True
+        if self.agent.instructions:
+            base_prompt += f"\nThis is your instructions to follow: {self.agent.instructions}"
+            has_any_info = True
+        if self.agent.education:
+            base_prompt += f"\nThis is your education: {self.agent.education}"
+            has_any_info = True
+        if self.agent.work_experience:
+            base_prompt += f"\nThis is your work experiences: {self.agent.work_experience}"
+            has_any_info = True
+
+        if self.agent.company_name:
+            base_prompt += f"\nYour company name is: {self.agent.company_name}"
+            has_any_info = True
+        if self.agent.company_url:
+            base_prompt += f"\nYour company website is: {self.agent.company_url}"
+            has_any_info = True
+        if self.agent.company_objective:
+            base_prompt += f"\nYour company objective is: {self.agent.company_objective}"
+            has_any_info = True
+        if self.agent.company_description:
+            base_prompt += f"\nYour company description is: {self.agent.company_description}"
+            has_any_info = True
+            
+        
+        
+        if not self.agent.system_prompt and not has_any_info and not is_thinking_enabled:
+            base_prompt = default_prompt().prompt
         
         prompt_parts.append(base_prompt.strip())
 
