@@ -1,5 +1,14 @@
+from __future__ import annotations
+
 import time
-from typing import Optional, Type, Union, TypeVar, List
+from typing import Optional, Type, Union, TypeVar, List, TYPE_CHECKING
+
+if TYPE_CHECKING:
+    from motor.motor_asyncio import (
+        AsyncIOMotorClient,
+        AsyncIOMotorDatabase,
+        AsyncIOMotorCollection,
+    )
 
 try:
     from motor.motor_asyncio import (
@@ -7,13 +16,12 @@ try:
         AsyncIOMotorDatabase,
         AsyncIOMotorCollection,
     )
-except ImportError as _import_error:
-    from upsonic.utils.printing import import_error
-    import_error(
-        package_name="motor",
-        install_command='pip install "upsonic[storage]"',
-        feature_name="MongoDB storage provider"
-    )
+    _MOTOR_AVAILABLE = True
+except ImportError:
+    AsyncIOMotorClient = None  # type: ignore
+    AsyncIOMotorDatabase = None  # type: ignore
+    AsyncIOMotorCollection = None  # type: ignore
+    _MOTOR_AVAILABLE = False
 
 from pydantic import BaseModel
 
@@ -47,6 +55,14 @@ class MongoStorage(Storage):
             sessions_collection_name: The name of the collection for InteractionSession.
             profiles_collection_name: The name of the collection for UserProfile.
         """
+        if not _MOTOR_AVAILABLE:
+            from upsonic.utils.printing import import_error
+            import_error(
+                package_name="motor",
+                install_command='pip install "upsonic[storage]"',
+                feature_name="MongoDB storage provider"
+            )
+
         super().__init__()
         self.db_url = db_url
         self.database_name = database_name
