@@ -1,16 +1,16 @@
 from __future__ import annotations
 
-import logging
 from typing import Dict, List, NamedTuple, Optional
 import re
 
-from pydantic import Field
+from pydantic import Field, ConfigDict
 
 from upsonic.text_splitter.base import BaseChunker, BaseChunkingConfig
 from upsonic.schemas.data_models import Chunk, Document
 from upsonic.text_splitter.recursive import RecursiveChunker, RecursiveChunkingConfig
+from upsonic.utils.logging_config import get_logger
 
-logger = logging.getLogger(__name__)
+logger = get_logger(__name__)
 
 def get_default_text_chunker() -> BaseChunker:
     """A factory function to create a default text chunker instance."""
@@ -65,8 +65,7 @@ class MarkdownChunkingConfig(BaseChunkingConfig):
         exclude=True
     )
 
-    class Config:
-        arbitrary_types_allowed = True
+    model_config = ConfigDict(arbitrary_types_allowed=True)
 
 # Rebuild the model to resolve forward references
 MarkdownChunkingConfig.model_rebuild()
