@@ -1,19 +1,25 @@
-from typing import Any, Dict, List, Optional, Union, Literal
+from __future__ import annotations
+
+from typing import Any, Dict, List, Optional, Union, Literal, TYPE_CHECKING
 from collections import defaultdict
 
+if TYPE_CHECKING:
+    from qdrant_client import QdrantClient, models
+    from qdrant_client.http.exceptions import UnexpectedResponse
+
 try:
     from qdrant_client import QdrantClient, models
     from qdrant_client.http.exceptions import UnexpectedResponse
-except ImportError as _import_error:
-    from upsonic.utils.printing import import_error
-    import_error(
-        package_name="qdrant-client",
-        install_command='pip install "upsonic[rag]"',
-        feature_name="Qdrant vector database provider"
-    )
+    _QDRANT_AVAILABLE = True
+except ImportError:
+    QdrantClient = None  # type: ignore
+    models = None  # type: ignore
+    UnexpectedResponse = None  # type: ignore
+    _QDRANT_AVAILABLE = False
 
 
 from upsonic.vectordb.base import BaseVectorDBProvider
+from upsonic.utils.printing import info_log, debug_log, warning_log
 
 from upsonic.vectordb.config import (
     Config,
@@ -48,12 +54,6 @@ class QdrantProvider(BaseVectorDBProvider):
     collection from connection and creation to deletion.
     """
 
-    DISTANCE_MAP = {
-        DistanceMetric.COSINE: models.Distance.COSINE,
-        DistanceMetric.EUCLIDEAN: models.Distance.EUCLID,
-        DistanceMetric.DOT_PRODUCT: models.Distance.DOT,
-    }
-
     def __init__(self, config: Config):
         """
         Initializes the QdrantProvider.
@@ -61,6 +61,14 @@ class QdrantProvider(BaseVectorDBProvider):
         Validates that the provided configuration is compatible with Qdrant's
         capabilities before proceeding.
         """
+        if not _QDRANT_AVAILABLE:
+            from upsonic.utils.printing import import_error
+            import_error(
+                package_name="qdrant-client",
+                install_command='pip install "upsonic[rag]"',
+                feature_name="Qdrant vector database provider"
+            )
+
         super().__init__(config)
         if isinstance(self._config.indexing.index_config, IVFTuningConfig):
             raise ConfigurationError(
@@ -80,7 +88,7 @@ class QdrantProvider(BaseVectorDBProvider):
             VectorDBConnectionError: If the connection fails for any reason.
         """
         if self._is_connected:
-            print("Already connected to Qdrant.")
+            info_log("Already connected to Qdrant.", context="QdrantVectorDB")
             return
 
         core_cfg = self._config.core
@@ -110,7 +118,7 @@ class QdrantProvider(BaseVectorDBProvider):
                 raise ConfigurationError(f"Unsupported mode for Qdrant: {core_cfg.mode.value}")
 
             self._is_connected = True
-            print("Successfully connected to Qdrant.")
+            info_log("Successfully connected to Qdrant.", context="QdrantVectorDB")
 
         except Exception as e:
             self._client = None
@@ -136,9 +144,11 @@ class QdrantProvider(BaseVectorDBProvider):
                 elif hasattr(self._client, 'close'):
                     self._client.close()
                 
-                print("Successfully disconnected from Qdrant.")
+                from upsonic.utils.printing import success_log
+                success_log("Successfully disconnected from Qdrant.", "QdrantProvider")
             except Exception as e:
-                print(f"Error during Qdrant disconnection: {e}")
+                from upsonic.utils.printing import error_log
+                error_log(f"Error during Qdrant disconnection: {e}", "QdrantProvider")
             finally:
                 self._client = None
                 self._is_connected = False
@@ -154,9 +164,11 @@ class QdrantProvider(BaseVectorDBProvider):
                 elif hasattr(self._client, 'close'):
                     self._client.close()
                 
-                print("Successfully disconnected from Qdrant.")
+                from upsonic.utils.printing import success_log
+                success_log("Successfully disconnected from Qdrant.", "QdrantProvider")
             except Exception as e:
-                print(f"Error during Qdrant disconnection: {e}")
+                from upsonic.utils.printing import error_log
+                error_log(f"Error during Qdrant disconnection: {e}", "QdrantProvider")
             finally:
                 self._client = None
                 self._is_connected = False
@@ -184,12 +196,19 @@ class QdrantProvider(BaseVectorDBProvider):
         
         try:
             if self._config.core.recreate_if_exists and self.collection_exists():
-                print(f"Collection '{collection_name}' exists and `recreate_if_exists` is True. Deleting...")
+                info_log(f"Collection '{collection_name}' exists and `recreate_if_exists` is True. Deleting...", context="QdrantVectorDB")
                 self.delete_collection()
             
+            # Map distance metrics
+            distance_map = {
+                DistanceMetric.COSINE: models.Distance.COSINE,
+                DistanceMetric.EUCLIDEAN: models.Distance.EUCLID,
+                DistanceMetric.DOT_PRODUCT: models.Distance.DOT,
+            }
+
             vectors_config = models.VectorParams(
                 size=self._config.core.vector_size,
-                distance=self.DISTANCE_MAP[self._config.core.distance_metric]
+                distance=distance_map[self._config.core.distance_metric]
             )
 
             hnsw_config = None
@@ -224,7 +243,7 @@ class QdrantProvider(BaseVectorDBProvider):
                 shard_number=sharding_cfg.num_shards,
                 replication_factor=sharding_cfg.replication_factor,
             )
-            print(f"Successfully created or configured collection '{collection_name}'.")
+            info_log(f"Successfully created or configured collection '{collection_name}'.", context="QdrantVectorDB")
             if self._config.indexing.payload_indexes:
                 self._create_payload_indexes(collection_name)
 
@@ -254,7 +273,7 @@ class QdrantProvider(BaseVectorDBProvider):
                     else:
                         raise VectorDBError(f"Failed to delete collection '{collection_name}' but it still exists.")
                     
-            print(f"Successfully deleted collection '{collection_name}'.")
+            info_log(f"Successfully deleted collection '{collection_name}'.", context="QdrantVectorDB")
         except UnexpectedResponse as e:
             if e.status_code == 404:
                 raise CollectionDoesNotExistError(f"Collection '{collection_name}' does not exist.") from e
@@ -652,7 +671,7 @@ class QdrantProvider(BaseVectorDBProvider):
         """
         Private helper method to create payload indexes on a collection.
         """
-        print("Applying payload indexes...")
+        debug_log("Applying payload indexes...", context="QdrantVectorDB")
         schema_map = {
             'text': models.TextIndexParams,
             'keyword': models.KeywordIndexParams,
@@ -668,7 +687,7 @@ class QdrantProvider(BaseVectorDBProvider):
             params = index_config.params or {}
 
             if schema_type not in schema_map:
-                print(f"Warning: Unknown payload index schema type '{schema_type}'. Skipping field '{field_name}'.")
+                warning_log(f"Unknown payload index schema type '{schema_type}'. Skipping field '{field_name}'.", context="QdrantVectorDB")
                 continue
 
             try:
@@ -687,7 +706,7 @@ class QdrantProvider(BaseVectorDBProvider):
                 else:
                     qdrant_schema = schema_map[schema_type](**params)
                 
-                print(f"  - Creating index for field '{field_name}' of type '{schema_type}'...")
+                debug_log(f"Creating index for field '{field_name}' of type '{schema_type}'...", context="QdrantVectorDB")
                 self._client.create_payload_index(
                     collection_name=collection_name,
                     field_name=field_name,
@@ -700,4 +719,4 @@ class QdrantProvider(BaseVectorDBProvider):
                     f"Failed to create payload index for field '{field_name}' "
                     f"in collection '{collection_name}': {e}"
                 ) from e
-        print("Payload indexes applied successfully.")
\ No newline at end of file
+        info_log("Payload indexes applied successfully.", context="QdrantVectorDB")
\ No newline at end of file
